@@ -1,14 +1,5 @@
-#!/usr/bin/env perl
-#
-# This file is part of Pod-Browser
-#
-# This software is Copyright (c) 2012 by Moritz Onken.
-#
-# This is free software, licensed under:
-#
-#   The (three-clause) BSD License
-#
-# PODNAME: pod_browser_fastcgi.pl
+#!/usr/bin/perl -w
+
 BEGIN { $ENV{CATALYST_ENGINE} ||= 'FastCGI' }
 
 use strict;
@@ -21,7 +12,7 @@ use Pod::Browser;
 
 my $help = 0;
 my ( $listen, $nproc, $pidfile, $manager, $detach, $keep_stderr );
-
+ 
 GetOptions(
     'help|?'      => \$help,
     'listen|l=s'  => \$listen,
@@ -34,34 +25,26 @@ GetOptions(
 
 pod2usage(1) if $help;
 
-Pod::Browser->run(
-    $listen,
+Pod::Browser->run( 
+    $listen, 
     {   nproc   => $nproc,
-        pidfile => $pidfile,
+        pidfile => $pidfile, 
         manager => $manager,
         detach  => $detach,
-        keep_stderr => $keep_stderr,
+	keep_stderr => $keep_stderr,
     }
 );
 
 1;
 
-
-__END__
-=pod
-
 =head1 NAME
 
-pod_browser_fastcgi.pl
-
-=head1 VERSION
-
-version 0.9.1
+pod_browser_fastcgi.pl - Catalyst FastCGI
 
 =head1 SYNOPSIS
 
 pod_browser_fastcgi.pl [options]
-
+ 
  Options:
    -? -help      display this help and exits
    -l -listen    Socket path to listen on
@@ -80,17 +63,18 @@ pod_browser_fastcgi.pl [options]
    -e -keeperr   send error messages to STDOUT, not
                  to the webserver
 
+=head1 DESCRIPTION
+
+Run a Catalyst application as fastcgi.
+
 =head1 AUTHOR
 
-Moritz Onken <onken@netcubed.de>
+Sebastian Riedel, C<sri@oook.de>
+Maintained by the Catalyst Core Team.
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
-This software is Copyright (c) 2012 by Moritz Onken.
-
-This is free software, licensed under:
-
-  The (three-clause) BSD License
+This library is free software, you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
-
